tiled.client.array.DaskArrayClient
==================================

.. currentmodule:: tiled.client.array

.. autoclass:: DaskArrayClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskArrayClient.__init__
      ~DaskArrayClient.download
      ~DaskArrayClient.export
      ~DaskArrayClient.new_variation
      ~DaskArrayClient.read
      ~DaskArrayClient.read_block
      ~DaskArrayClient.refresh
      ~DaskArrayClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskArrayClient.context
      ~DaskArrayClient.dims
      ~DaskArrayClient.formats
      ~DaskArrayClient.item
      ~DaskArrayClient.metadata
      ~DaskArrayClient.offline
      ~DaskArrayClient.path
      ~DaskArrayClient.uri
      ~DaskArrayClient.username
   
   